@@ -4,10 +4,8 @@ Settings used by django-python3.
 
 from django.conf import settings
 
-from django_python3_ldap.utils import clean_user_data
 
-
-class LazySetting():
+class LazySetting(object):
 
     """
     A proxy to a named Django setting.
@@ -23,7 +21,7 @@ class LazySetting():
         return getattr(obj._settings, self.name, self.default)
 
 
-class LazySettings():
+class LazySettings(object):
 
     """
     A proxy to ldap-specific django settings.
@@ -35,32 +33,26 @@ class LazySettings():
     def __init__(self, settings):
         self._settings = settings
 
-    # The URL of the LDAP server.
     LDAP_AUTH_URL = LazySetting(
         name = "LDAP_AUTH_URL",
         default = "ldap://localhost:389",
     )
 
-    # Initiate TLS on connection.
     LDAP_AUTH_USE_TLS = LazySetting(
         name = "LDAP_AUTH_USE_TLS",
         default = False,
     )
 
-    # The LDAP search base for looking up users.
     LDAP_AUTH_SEARCH_BASE = LazySetting(
         name = "LDAP_AUTH_SEARCH_BASE",
         default = "ou=people,dc=example,dc=com",
     )
 
-    # The LDAP class that represents a user.
     LDAP_AUTH_OBJECT_CLASS = LazySetting(
         name = "LDAP_AUTH_OBJECT_CLASS",
         default = "inetOrgPerson",
     )
 
-    # User model fields mapped to the LDAP
-    # attributes that represent them.
     LDAP_AUTH_USER_FIELDS = LazySetting(
         name = "LDAP_AUTH_USER_FIELDS",
         default = {
@@ -71,7 +63,6 @@ class LazySettings():
         },
     )
 
-    # A tuple of fields used to uniquely identify a user.
     LDAP_AUTH_USER_LOOKUP_FIELDS = LazySetting(
         name = "LDAP_AUTH_USER_LOOKUP_FIELDS",
         default = (
@@ -79,24 +70,50 @@ class LazySettings():
         ),
     )
 
-    # Transforms the user data loaded from
-    # LDAP into a form suitable for creating a user.
     LDAP_AUTH_CLEAN_USER_DATA = LazySetting(
         name = "LDAP_AUTH_CLEAN_USER_DATA",
-        default = clean_user_data,
+        default = "django_python3_ldap.utils.clean_user_data",
+    )
+
+    LDAP_AUTH_FORMAT_SEARCH_FILTERS = LazySetting(
+        name = "LDAP_AUTH_FORMAT_SEARCH_FILTERS",
+        default = "django_python3_ldap.utils.format_search_filters",
+    )
+
+    LDAP_AUTH_SYNC_USER_RELATIONS = LazySetting(
+        name = "LDAP_AUTH_SYNC_USER_RELATIONS",
+        default = "django_python3_ldap.utils.sync_user_relations",
+    )
+
+    LDAP_AUTH_FORMAT_USERNAME = LazySetting(
+        name = "LDAP_AUTH_FORMAT_USERNAME",
+        default = "django_python3_ldap.utils.format_username_openldap",
+    )
+
+    LDAP_AUTH_ACTIVE_DIRECTORY_DOMAIN = LazySetting(
+        name = "LDAP_AUTH_ACTIVE_DIRECTORY_DOMAIN",
+        default = None,
     )
 
-    # A username to use when running the live LDAP tests.
     LDAP_AUTH_TEST_USER_USERNAME = LazySetting(
         name = "LDAP_AUTH_TEST_USER_USERNAME",
         default = "",
     )
 
-    # A password to use when running the live LDAP tests.
     LDAP_AUTH_TEST_USER_PASSWORD = LazySetting(
         name = "LDAP_AUTH_TEST_USER_PASSWORD",
         default = "",
     )
 
+    LDAP_AUTH_CONNECTION_USERNAME = LazySetting(
+        name = "LDAP_AUTH_CONNECTION_USERNAME",
+        default = None,
+    )
+
+    LDAP_AUTH_CONNECTION_PASSWORD = LazySetting(
+        name = "LDAP_AUTH_CONNECTION_PASSWORD",
+        default = None,
+    )
+
 
 settings = LazySettings(settings)
