@@ -67,13 +67,14 @@ class Connection(object):
             search_base = settings.LDAP_AUTH_SEARCH_BASE,
             search_filter = format_search_filter({}),
             search_scope = ldap3.SEARCH_SCOPE_WHOLE_SUBTREE,
-            attributes = list(settings.LDAP_AUTH_USER_FIELDS.values()),
+            attributes = ldap3.ALL_ATTRIBUTES,
             paged_size = 30,
         )
         return (
             self._get_or_create_user(entry)
             for entry
             in paged_entries
+            if entry["type"] == "searchResEntry"
         )
 
     def get_user(self, **kwargs):
@@ -89,6 +90,7 @@ class Connection(object):
             search_filter = format_search_filter(kwargs),
             search_scope = ldap3.SEARCH_SCOPE_WHOLE_SUBTREE,
             attributes = ldap3.ALL_ATTRIBUTES,
+            get_operational_attributes = True,
             size_limit = 1,
         ):
             return self._get_or_create_user(self._connection.response[0])
@@ -134,7 +136,7 @@ def authenticate(**kwargs):
     """
     password = kwargs.pop("password")
     # Check that this is valid login data.
-    if password is None or frozenset(kwargs.keys()) != frozenset(settings.LDAP_AUTH_USER_LOOKUP_FIELDS):
+    if not password or frozenset(kwargs.keys()) != frozenset(settings.LDAP_AUTH_USER_LOOKUP_FIELDS):
         return None
     # Connect to LDAP.
     with connection(password=password, **kwargs) as c:
