@@ -2,6 +2,7 @@ from django.core.management.base import NoArgsCommand
 from django.db import transaction
 
 from django_python3_ldap import ldap
+from django_python3_ldap.conf import settings
 
 
 class Command(NoArgsCommand):
@@ -11,7 +12,7 @@ class Command(NoArgsCommand):
     @transaction.atomic()
     def handle_noargs(self, **kwargs):
         verbosity = int(kwargs.get("verbosity", 1))
-        with ldap.connection() as connection:
+        with ldap.connection(username=settings.LDAP_AUTH_CONNECTION_USERNAME, password=settings.LDAP_AUTH_CONNECTION_PASSWORD) as connection:
             for user in connection.iter_users():
                 if verbosity >= 1:
                     self.stdout.write("Synced {user}".format(
