@@ -1,14 +1,19 @@
+# encoding=utf-8
+from __future__ import unicode_literals
+
 from unittest import skipUnless
-from io import StringIO
+from io import StringIO, BytesIO
 
 from django.test import TestCase
 from django.contrib.auth import authenticate
 from django.contrib.auth.models import User
 from django.conf import settings as django_settings
 from django.core.management import call_command, CommandError
+from django.utils import six
 
 from django_python3_ldap.conf import settings
 from django_python3_ldap.ldap import connection
+from django_python3_ldap.utils import clean_ldap_name, import_func
 
 
 @skipUnless(settings.LDAP_AUTH_TEST_USER_USERNAME, "No settings.LDAP_AUTH_TEST_USER_USERNAME supplied.")
@@ -18,7 +23,7 @@ from django_python3_ldap.ldap import connection
 class TestLdap(TestCase):
 
     def setUp(self):
-        super().setUp()
+        super(TestLdap, self).setUp()
         User.objects.all().delete()
 
     # Lazy settings tests.
@@ -30,31 +35,14 @@ class TestLdap(TestCase):
         self.assertEqual(settings.__class__.LDAP_AUTH_TEST_USER_USERNAME.name, "LDAP_AUTH_TEST_USER_USERNAME")
         self.assertEqual(settings.__class__.LDAP_AUTH_TEST_USER_USERNAME.default, "")
 
+    # Utils tests.
+
+    def testCleanLdapName(self):
+        self.assertEqual(clean_ldap_name("foo@bar.com"), r'foo@bar.com')
+        self.assertEqual(clean_ldap_name("café"), r'caf\E9')
+
     # LDAP tests.
 
-    def testGetUserArgsSuccess(self):
-        with connection() as c:
-            user = c.get_user(
-                settings.LDAP_AUTH_TEST_USER_USERNAME,
-            )
-            self.assertIsInstance(user, User)
-            self.assertEqual(user.username, settings.LDAP_AUTH_TEST_USER_USERNAME)
-
-    def testGetUserArgsIncorrectUsername(self):
-        with connection() as c:
-            user = c.get_user(
-                "bad" + settings.LDAP_AUTH_TEST_USER_USERNAME,
-            )
-            self.assertEqual(user, None)
-
-    def testGetUserArgsExtraField(self):
-        with self.assertRaises(TypeError, msg="Expected arguments: username"):
-            with connection() as c:
-                c.get_user(
-                    settings.LDAP_AUTH_TEST_USER_USERNAME,
-                    "foo",
-                )
-
     def testGetUserKwargsSuccess(self):
         with connection() as c:
             user = c.get_user(
@@ -70,27 +58,6 @@ class TestLdap(TestCase):
             )
             self.assertEqual(user, None)
 
-    def testGetUserKwrgsExtraField(self):
-        with self.assertRaises(TypeError, msg="Expected arguments: username"):
-            with connection() as c:
-                c.get_user(
-                    username = settings.LDAP_AUTH_TEST_USER_USERNAME,
-                    foo = "foo",
-                )
-
-    def testGetUserBothArgsAndKwargs(self):
-        with self.assertRaises(TypeError, msg="Cannot use both args and kwargs to identify a user"):
-            with connection() as c:
-                c.get_user(
-                    settings.LDAP_AUTH_TEST_USER_USERNAME,
-                    username = settings.LDAP_AUTH_TEST_USER_USERNAME,
-                )
-
-    def testGetUserMissingArgsAndKwargs(self):
-        with self.assertRaises(TypeError, msg="Expected arguments: username"):
-            with connection() as c:
-                c.get_user()
-
     # Authentication tests.
 
     def testAuthenticateUserSuccess(self):
@@ -100,7 +67,7 @@ class TestLdap(TestCase):
         )
         self.assertIsInstance(user, User)
         self.assertEqual(user.username, settings.LDAP_AUTH_TEST_USER_USERNAME)
-        
+
     def testAuthenticateUserBadUsername(self):
         user = authenticate(
             username = "bad" + settings.LDAP_AUTH_TEST_USER_USERNAME,
@@ -127,6 +94,15 @@ class TestLdap(TestCase):
         # Ensure that the user isn't recreated on second access.
         self.assertEqual(user_1.pk, user_2.pk)
 
+    def testAuthenticateWithTLS(self):
+        with self.settings(LDAP_AUTH_USE_TLS=True):
+            user = authenticate(
+                username = settings.LDAP_AUTH_TEST_USER_USERNAME,
+                password = settings.LDAP_AUTH_TEST_USER_PASSWORD,
+            )
+            self.assertIsInstance(user, User)
+            self.assertEqual(user.username, settings.LDAP_AUTH_TEST_USER_USERNAME)
+
     # User syncronisation.
 
     def testSyncUsersCreatesUsers(self):
@@ -134,12 +110,12 @@ class TestLdap(TestCase):
         self.assertGreater(User.objects.count(), 0)
 
     def testSyncUsersCommandOutput(self):
-        out = StringIO()
+        out = StringIO() if six.PY3 else BytesIO()
         call_command("ldap_sync_users", verbosity=1, stdout=out)
         rows = out.getvalue().split("\n")[:-1]
         self.assertEqual(len(rows), User.objects.count())
         for row in rows:
-            self.assertRegex(row, r'^Synced [^\s]+$')
+            six.assertRegex(self, row, r'^Synced [^\s]+$')
 
     def testReSyncUsersDoesntRecreateUsers(self):
         call_command("ldap_sync_users", verbosity=0)
@@ -157,7 +133,7 @@ class TestLdap(TestCase):
         self.assertFalse(user.is_staff)
         self.assertFalse(user.is_superuser)
         # Promote the user.
-        call_command("ldap_promote", "test", stdout=StringIO())
+        call_command("ldap_promote", "test", stdout=StringIO() if six.PY3 else BytesIO())
         user = User.objects.get(username="test")
         self.assertTrue(user.is_staff)
         self.assertTrue(user.is_superuser)
@@ -165,3 +141,38 @@ class TestLdap(TestCase):
     def testPromoteMissingUser(self):
         with self.assertRaises(CommandError, msg="User with username missing_user does not exist") as cm:
             call_command("ldap_promote", "missing_user", verbosity=0)
+
+    def testSyncUserRelations(self):
+        def check_sync_user_relation(user, data):
+            # id have been created
+            self.assertIsNotNone(user.id)
+            # model is saved
+            self.assertEqual(user.username, User.objects.get(pk=user.id).username)
+            # save all groups
+            self.assertIn('cn', data)
+            groups = list()
+            ldap_groups = list(data.get('memberOf', ()))
+            ldap_groups.append('default_group')
+            for group in ldap_groups:
+                user.groups.create(name=group)
+
+        with self.settings(LDAP_AUTH_SYNC_USER_RELATIONS=check_sync_user_relation):
+            user = authenticate(
+                username = settings.LDAP_AUTH_TEST_USER_USERNAME,
+                password = settings.LDAP_AUTH_TEST_USER_PASSWORD,
+            )
+            self.assertIsInstance(user, User)
+            self.assertGreaterEqual(user.groups.count(), 1)
+            self.assertEqual(user.groups.filter(name='default_group').count(), 1)
+
+    def testImportFunc(self):
+        self.assertIs(clean_ldap_name, import_func(clean_ldap_name))
+        self.assertIs(clean_ldap_name, import_func('django_python3_ldap.utils.clean_ldap_name'))
+        self.assertTrue(callable(import_func('django.contrib.auth.get_user_model')))
+
+        self.assertRaises(AttributeError, import_func, 123)
+
+        self.assertTrue(callable(import_func(settings.LDAP_AUTH_SYNC_USER_RELATIONS)))
+
+        with self.settings(LDAP_AUTH_SYNC_USER_RELATIONS='django.contrib.auth.get_user_model'):
+            self.assertTrue(callable(import_func(settings.LDAP_AUTH_SYNC_USER_RELATIONS)))
